import { TrieNode } from './TrieNode';
export declare type CompoundModes = 'none' | 'compound' | 'legacy';
export interface FindOptions {
    matchCase: boolean;
    compoundMode: CompoundModes;
    forbidPrefix: string;
    compoundFix: string;
    caseInsensitivePrefix: string;
    legacyMinCompoundLength: number;
}
export declare type PartialFindOptions = Partial<FindOptions> | undefined;
export interface FindNodeResult {
    node: TrieNode | undefined;
}
export interface FindResult {
    found: string | false;
    compoundUsed: boolean;
    caseMatched: boolean;
}
export interface FindFullResult extends FindResult {
    forbidden: boolean;
}
export interface FindFullNodeResult extends FindNodeResult, FindFullResult {
}
/**
 *
 * @param root Trie root node. root.c contains the compound root and forbidden root.
 * @param word A pre normalized word use `normalizeWord` or `normalizeWordToLowercase`
 * @param options
 */
export declare function findWord(root: TrieNode, word: string, options?: PartialFindOptions): FindFullResult;
/**
 *
 * @param root Trie root node. root.c contains the compound root and forbidden root.
 * @param word A pre normalized word use `normalizeWord` or `normalizeWordToLowercase`
 * @param options
 */
export declare function findWordNode(root: TrieNode, word: string, options?: PartialFindOptions): FindFullNodeResult;
export declare function findLegacyCompound(root: TrieNode, word: string, options: FindOptions): FindFullNodeResult;
export declare function findCompoundNode(root: TrieNode | undefined, word: string, compoundCharacter: string, possiblePrefix: string): FindFullNodeResult;
export declare function findWordExact(root: TrieNode | undefined, word: string): boolean;
export declare function isEndOfWordNode(n: TrieNode | undefined): boolean;
declare function findLegacyCompoundWord(roots: (TrieNode | undefined)[], word: string, minCompoundLength: number): FindResult;
export declare function isForbiddenWord(root: TrieNode | undefined, word: string, forbiddenPrefix: string): boolean;
export declare function createFindOptions(options: PartialFindOptions | undefined): FindOptions;
export declare const __testing__: {
    findLegacyCompoundWord: typeof findLegacyCompoundWord;
};
export {};
