import { TrieRoot } from './TrieNode';
import { CompoundWordsMethod } from './walker';
export declare type Cost = number;
export declare type MaxCost = Cost;
export interface SuggestionResult {
    word: string;
    cost: Cost;
}
/**
 * Ask for the next result.
 * maxCost - sets the max cost for following suggestions
 * This is used to limit which suggestions are emitted.
 * If the iterator.next() returns `undefined`, it is to request a value for maxCost.
 */
export declare type SuggestionIterator = Generator<SuggestionResult, undefined, MaxCost | undefined>;
export declare function suggest(root: TrieRoot, word: string, maxNumSuggestions?: number, compoundMethod?: CompoundWordsMethod, numChanges?: number): SuggestionResult[];
export declare function genSuggestions(root: TrieRoot, word: string, compoundMethod?: CompoundWordsMethod): SuggestionIterator;
export declare function genCompoundableSuggestions(root: TrieRoot, word: string, compoundMethod: CompoundWordsMethod): SuggestionIterator;
export declare function compSuggestionResults(a: SuggestionResult, b: SuggestionResult): number;
export interface SuggestionCollector {
    collect: (src: SuggestionIterator) => void;
    add: (suggestion: SuggestionResult) => SuggestionCollector;
    readonly suggestions: SuggestionResult[];
    readonly maxCost: number;
    readonly word: string;
    readonly maxNumSuggestions: number;
    readonly includesTies: boolean;
}
export declare function suggestionCollector(wordToMatch: string, maxNumSuggestions: number, filter?: (word: string, cost: number) => boolean, changeLimit?: number, includeTies?: boolean): SuggestionCollector;
